@@ -25,8 +25,9 @@ use utf8;
 use ClearPress::Localize;
 use MIME::Base64 qw(encode_base64);
 
-our $VERSION = q[473.0.2];
+our $VERSION = q[473.0.5];
 our $DEBUG_OUTPUT   = 0;
+our $DEBUG_L10N     = 0;
 our $TEMPLATE_CACHE = {};
 our $LEXICON_CACHE  = {};
 
@@ -120,8 +121,10 @@ sub setup_filters {
                                    my $loc = $string;
                                    eval {
                                      $loc = $util->{localizers}->{$lang}->maketext($string);
+                                     1;
                                    } or do {
-                                     carp qq[Could not localize $string to $lang];
+                                     $DEBUG_L10N && carp qq[Could not localize $string to $lang];
+                                     1;
                                    };
 
                                    return $loc || $string;
@@ -1093,6 +1096,10 @@ e.g.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
+ Set $ClearPress::view::DEBUG_L10N = 1 to report missing locali[zs]ation strings.
+
+ Set $ClearPress::view::DEBUG_OUTPUT = 1 to report output buffer operations.
+
 =head1 DEPENDENCIES
 
 =over
